"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.validatePart = validatePart;
exports.validate = validate;
exports.normalize = normalize;
exports.buildUrl = buildUrl;
exports.default = void 0;
const DOI_VALIDATION_PATTERN = /^10.\d{4,9}\/[-._;()/:A-Z0-9]+$/i; // source: https://www.crossref.org/blog/dois-and-matching-regular-expressions/
// const DOI_URL_PATTERN = /(?:https?:\/\/)?(?:dx\.)?(?:www\.)?doi.org\//;
const repos = {
    zenodo: '10.5281/zenodo.',
    elife: '10.7554/eLife.'
};
function validatePart(possibleDOI) {
    if (!possibleDOI) return false;
    return possibleDOI.match(DOI_VALIDATION_PATTERN) !== null;
}
function validate(possibleDOI) {
    if (!possibleDOI) return false;
    return !!normalize(possibleDOI);
}
function normalize(possibleDOI) {
    let doi = undefined;
    if (!possibleDOI) return undefined;
    if (validatePart(possibleDOI)) return possibleDOI;
    if (possibleDOI.startsWith('doi:')) {
        doi = possibleDOI.slice(4);
        if (validatePart(doi)) return doi;
    }
    try {
        const url = new URL(possibleDOI.startsWith('http') ? possibleDOI : `http://${possibleDOI}`);
        if (url.hostname.match(/(?:dx\.)?(?:www\.)?doi\.org/)) {
            doi = url.pathname.replace(/^\//, '');
        }
        if (url.hostname.match(/(?:^|\.)doi./) || url.pathname.includes('/doi/')) {
            doi = url.pathname.replace(/\/doi\//, '').replace(/^\//, '');
        }
        if (url.hostname.endsWith('elifesciences.org') && url.pathname.startsWith('/articles/') && !url.hash // Can have a #bib1 which we don't want
        ) {
            doi = `${repos.elife}${url.pathname.replace('/articles/', '')}`;
        }
        if (url.hostname.endsWith('zenodo.org') && url.pathname.match(/^\/(?:record|badge\/latestdoi)\//)) {
            doi = `${repos.zenodo}${url.pathname.replace(/^\/(?:record|badge\/latestdoi)\//, '')}`;
        }
    } catch (error) {
    // pass
    }
    if (validatePart(doi)) return doi;
    return undefined;
}
function buildUrl(possibleDOI) {
    const doi = normalize(possibleDOI);
    if (!doi) return undefined;
    return `https://doi.org/${doi}`;
}
var _default = {
    validatePart,
    validate,
    normalize,
    buildUrl
};
exports.default = _default;

//# sourceMappingURL=index.js.map