"use strict";
var _index = require("./index");
describe('validate', ()=>{
    test('should return true if doi is correct', ()=>{
        expect((0, _index).validate('10.1234/56789')).toBe(true);
    });
    test('empty is not a validPart', ()=>{
        expect((0, _index).validatePart()).toBe(false);
        expect((0, _index).validatePart('')).toBe(false);
    });
    test('empty is not valid', ()=>{
        expect((0, _index).validate()).toBe(false);
        expect((0, _index).validate('')).toBe(false);
    });
    test.each([
        'https://doi.org/10.1371/journal.pclm.0000068',
        'doi:10.1234/56789',
        '10.1234/56789',
        'doi.org/10.1371/journal.pclm.0000068', 
    ])('Validate works for %p', (valid)=>{
        expect((0, _index).validate(valid)).toBe(true);
    });
    // can expand on here if needed
    test.each([
        'https://doi.org/10.1371/journal.pclm.0000068',
        ':10.1234/56789a',
        'doi:10.1234/56789', 
    ])('should not validatePart when it is %p', (invalid)=>{
        expect((0, _index).validatePart(invalid)).toBe(false);
    });
});
describe('buildDoiUrl', ()=>{
    test('should build doi.org url with doi', ()=>{
        expect((0, _index).buildUrl('10.1234/56789')).toBe('https://doi.org/10.1234/56789');
    });
    test.each([
        [
            'http://dx.doi.org/10.1016/j.cageo.2015.09.015'
        ],
        [
            'http://www.doi.org/10.1016/j.cageo.2015.09.015'
        ],
        [
            'http://doi.org/10.1016/j.cageo.2015.09.015'
        ],
        [
            'www.doi.org/10.1016/j.cageo.2015.09.015'
        ],
        [
            'doi.org/10.1016/j.cageo.2015.09.015'
        ],
        [
            'doi.something.else/10.1016/j.cageo.2015.09.015'
        ],
        [
            'something.else/doi/10.1016/j.cageo.2015.09.015'
        ], 
    ])('should normalize url when it is %p', (doi)=>{
        expect((0, _index).buildUrl(doi)).toBe('https://doi.org/10.1016/j.cageo.2015.09.015');
    });
});
describe('normalize', ()=>{
    test('should remove "doi:"', ()=>{
        expect((0, _index).normalize('doi:10.1234/56789')).toBe('10.1234/56789');
    });
    test('should extract doi from doi.org url', ()=>{
        expect((0, _index).normalize('doi.org/10.1234/56789')).toBe('10.1234/56789');
    });
    test('should extract doi from doi.org url with http protocol', ()=>{
        expect((0, _index).normalize('https://doi.org/10.1234/56789')).toBe('10.1234/56789');
    });
    test('should handle www.', ()=>{
        expect((0, _index).normalize('http://www.doi.org/10.1234/56789')).toBe('10.1234/56789');
    });
});
describe('external DOI links', ()=>{
    test('Pull out domains that look like DOIs (subdomain)', ()=>{
        expect((0, _index).normalize('https://doi.pangaea.de/10.1594/PANGAEA.941238')).toBe('10.1594/PANGAEA.941238');
    });
    test('Pull out domains that look like DOIs (url)', ()=>{
        expect((0, _index).normalize('https://pangaea.de/doi/10.1594/PANGAEA.941238')).toBe('10.1594/PANGAEA.941238');
    });
    test('eLife', ()=>{
        expect((0, _index).normalize('https://elifesciences.org/articles/59045')).toBe('10.7554/eLife.59045');
        expect((0, _index).normalize('https://elifesciences.org/articles/59045#bib1')).toBeUndefined();
    });
    test('zenodo', ()=>{
        expect((0, _index).normalize('https://zenodo.org/badge/latestdoi/169800572')).toBe('10.5281/zenodo.169800572');
        expect((0, _index).normalize('https://zenodo.org/record/169800572')).toBe('10.5281/zenodo.169800572');
    });
});

//# sourceMappingURL=index.spec.js.map